@@ -53,6 +53,7 @@ from GitCommit import *
 from Github_ import *
 from GitRef import *
 from GitRelease import *
+from GitReleaseAsset import *
 from GitTag import *
 from GitTree import *
 from Hook import *
@@ -70,7 +71,6 @@ from Organization import *
 from PullRequest import *
 from PullRequestComment import *
 from PullRequestReview import *
-from PullRequestReviewerRequests import *
 from PullRequestFile import *
 from RateLimiting import *
 from Repository import *
